package com.karensrecipes.midlets.utils;

import java.io.*;
import java.util.*;
import javax.microedition.io.*;
import org.kxml.*;
import org.kxml.parser.*;
import com.karensrecipes.midlets.*;

public class RecipeSearchThread implements Runnable {
	
	private String keyword;
	private RecipeBrowser midlet;
	
	
	public RecipeSearchThread(RecipeBrowser midlet, String keyword) {
		this.midlet = midlet;
		this.keyword = keyword;
	}
	
	public void run() {
	
		// establish internet connection
		InputStream is = null;
		OutputStream os = null;
		HttpConnection conn = null;
		String query = "keyword=" + keyword;
		String requestMethod = HttpConnection.GET;
		String name = RecipeBrowser.QUERY_URL;
		
		
		try {
			conn = (HttpConnection)Connector.open(name + query, Connector.READ_WRITE);

			conn.setRequestMethod(requestMethod);
			// conn.setRequestProperty("Connection", "Close");
		
			// Read the response from the server
			is = conn.openInputStream();
			int code = conn.getResponseCode();
			
			String type = conn.getType();
			if (code == HttpConnection.HTTP_OK) {
				
				Vector v = new Vector();
				
				try {
					Reader reader = new InputStreamReader(is);
					XmlParser parser = new XmlParser(reader);
					ParseEvent pe = null;
	
					// skip the doctype
					parser.skip();
					parser.read(Xml.START_TAG, null, "recipes");
					
					// skip ?
					pe = parser.read();
					System.out.println(pe.getType());
					
					boolean trucking = true;
					
					Integer recipeid;
					while (trucking) {
						
						pe = parser.read();
						
						// if we find <recipe>
						if (pe.getType() == Xml.START_TAG) {
					  		
							// get the recipe id from the attribute
							Attribute a = pe.getAttribute("id");
							recipeid = Integer.valueOf(a.getValue());
							
							// fire read() again, get the text of <recipe>text</recipe>
							pe = parser.read();
							
							// construct a recipe object
							Recipe r = new Recipe(recipeid, pe.getText());
							
							// add it to  
							v.addElement(r);
							
						}
				  		
						// if we get to the end, then quit
						if (pe.getType() == Xml.END_TAG && pe.getName().equals("recipes")) {
							trucking = false;
						}
				  	}
					
				} catch (Exception e) {
					midlet.displayManager.pushDisplayable(new FormError(midlet, e.toString()));
				} 
				  
				// if we found some recipes, display them
				if (v.size() > 0) {
					midlet.displayManager.pushDisplayable(new ListRecipes(v, midlet));
				// otherwise, show an error message
				} else {
					midlet.displayManager.pushDisplayable(new FormContent(midlet, "There are no recipes that matched your search for '" + keyword + "'."));	
				}
				
			} else {
				// show the error form
				midlet.displayManager.pushDisplayable(new FormError(midlet, "code = " + code + ", type = " + type));
			}
			
		} catch (Exception io) {
			//show the error form
			midlet.displayManager.pushDisplayable(new FormError(midlet, "The application encountered an error. Message code = " + io.toString()));
		}
	}
}
